@@ -22,14 +22,15 @@ import pymongo
 import bson
 from son import SON
 from code import Code
-from errors import InvalidOperation, OperationFailure
+from errors import InvalidOperation, OperationFailure, ConnectionFailure
 
 _query_lock = Lock()
+_ZERO = "\x00\x00\x00\x00"
 
 class Cursor(object):
     """A cursor / iterator over Mongo query results.
     """
-    def __init__(self, collection, spec, fields, skip, limit):
+    def __init__(self, collection, spec, fields, skip, limit, _sock=None):
         """Create a new cursor.
 
         Should not be called directly by application developers.
@@ -42,6 +43,7 @@ class Cursor(object):
         self.__ordering = None
         self.__explain = False
         self.__hint = None
+        self.__socket = _sock
 
         self.__data = []
         self.__id = None
@@ -233,16 +235,16 @@ class Cursor(object):
             return len(self.__data)
 
         def send_message(operation, message):
-            _query_lock.acquire(1)
-            request_id = self.__collection._send_message(operation, message)
-            response = self.__collection.database().connection()._receive_message(1, request_id)
-            _query_lock.release()
+            response = self.__collection.database().connection()._receive_message(operation, message, _sock=self.__socket)
 
             response_flag = struct.unpack("<i", response[:4])[0]
             if response_flag == 1:
                 raise OperationFailure("cursor id '%s' not valid at server" % self.__id)
             elif response_flag == 2:
                 error_object = bson.BSON(response[20:]).to_dict()
+                if error_object["$err"] == "not master":
+                    self.__collection.database().connection()._reset()
+                    raise ConnectionFailure("master has changed")
                 raise OperationFailure("database error: %s" % error_object["$err"])
             else:
                 assert response_flag == 0
@@ -255,9 +257,11 @@ class Cursor(object):
             self.__data = bson._to_dicts(response[20:])
             assert len(self.__data) == number_returned
 
+        message = _ZERO
+        message += bson._make_c_string(self.__collection.full_name())
         if self.__id is None:
             # Query
-            message = struct.pack("<i", self.__skip)
+            message += struct.pack("<i", self.__skip)
             message += struct.pack("<i", -self.__limit)
             message += bson.BSON.from_dict(self.__query_spec())
             if self.__fields:
@@ -276,7 +280,7 @@ class Cursor(object):
                     self.__killed = True
                     return 0
 
-            message = struct.pack("<i", -limit)
+            message += struct.pack("<i", -limit)
             message += struct.pack("<q", self.__id)
 
             send_message(2005, message)
@@ -293,8 +297,4 @@ class Cursor(object):
             next = self.__collection.database()._fix_outgoing(self.__data.pop(0), self.__collection)
         else:
             raise StopIteration
-        # TODO should this be a SONManipulator? probably not...
-        # TODO check for not master and do something special in that case
-        if next.get("$err", False):
-            raise OperationFailure("db error: %s" % next["$err"])
         return next
