@@ -12,7 +12,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-"""Clean up script for build artifacts."""
+"""Clean up script for build artifacts.
+
+Only really intended to be used by internal build scripts.
+"""
 
 import os
-os.remove("pymongo/_cbson.so")
+try:
+    os.remove("pymongo/_cbson.so")
+except:
+    pass
